@@ -8,34 +8,37 @@ test_that("vbStarts() errors and warnings",{
   ## Get some data for the following attempts
   if (require(fishmethods)) {
     data(Kimura)
+    ## Asked for a dynamicPlot, which now does not exist
+    expect_warning(vbStarts(length~age,data=Kimura,dynamicPlot=TRUE),"functionality has been moved to")
     ## wrong types
-    expect_error(vbStarts(length~age,data=Kimura,type="Derek"))
-    expect_error(vbStarts(length~age,data=Kimura,type="Francis",methEV="Derek"))
-    expect_error(vbStarts(length~age,data=Kimura,type="Schnute",methEV="Derek"))
-    expect_error(vbStarts(length~age,data=Kimura,type="typical",meth0="Derek"))
-    expect_error(vbStarts(length~age,data=Kimura,type="original",meth0="Derek"))
+    expect_error(vbStarts(length~age,data=Kimura,param="Derek"),"should be one of")
+    expect_error(vbStarts(length~age,data=Kimura,type="Derek"),"should be one of")
+    expect_error(vbStarts(length~age,data=Kimura,param="Francis",methEV="Derek"),"should be one of")
+    expect_error(vbStarts(length~age,data=Kimura,param="Schnute",methEV="Derek"),"should be one of")
+    expect_error(vbStarts(length~age,data=Kimura,param="typical",meth0="Derek"),"should be one of")
+    expect_error(vbStarts(length~age,data=Kimura,param="original",meth0="Derek"),"should be one of")
     ## Two variables on LHS
-    expect_error(vbStarts(length+age~age,data=Kimura,type="typical"))
+    expect_error(vbStarts(length+age~age,data=Kimura,param="typical"),"more than one variable on the LHS")
     ## Two variables on RHS
-    expect_error(vbStarts(length~age+sex,data=Kimura,type="typical"))
+    expect_error(vbStarts(length~age+sex,data=Kimura,param="typical"),"must have only one RHS variable")
     ## LHS is a factor
-    expect_error(vbStarts(sex~age,data=Kimura,type="typical"))
+    expect_error(vbStarts(sex~age,data=Kimura,param="typical"),"LHS variable must be numeric")
     ## RHS is a factor
-    expect_error(vbStarts(length~sex,data=Kimura,type="typical"))
+    expect_error(vbStarts(length~sex,data=Kimura,param="typical"),"RHS variable must be numeric")
     ## not two ages2use given
-    expect_error(vbStarts(length~age,data=Kimura,type="Francis",ages2use=2))
-    expect_error(vbStarts(length~age,data=Kimura,type="Francis",ages2use=c(2,5,10)))
-    expect_error(vbStarts(length~age,data=Kimura,type="Schnute",ages2use=2))
-    expect_error(vbStarts(length~age,data=Kimura,type="Schnute",ages2use=c(2,5,10)))
+    expect_error(vbStarts(length~age,data=Kimura,param="Francis",ages2use=2),"have only two ages")
+    expect_error(vbStarts(length~age,data=Kimura,param="Francis",ages2use=c(2,5,10)),"have only two ages")
+    expect_error(vbStarts(length~age,data=Kimura,param="Schnute",ages2use=2),"have only two ages")
+    expect_error(vbStarts(length~age,data=Kimura,param="Schnute",ages2use=c(2,5,10)),"have only two ages")
     ## ages2use in wrong order
-    expect_warning(vbStarts(length~age,data=Kimura,type="Francis",ages2use=c(10,2)))
-    expect_warning(vbStarts(length~age,data=Kimura,type="Schnute",ages2use=c(10,2)))
+    expect_warning(vbStarts(length~age,data=Kimura,param="Francis",ages2use=c(10,2)),"order reversed to continue")
+    expect_warning(vbStarts(length~age,data=Kimura,param="Schnute",ages2use=c(10,2)),"order reversed to continue")
   }
   ## gives warning about a poor estimate for K and Linf
   if (require(FSAdata)) {
     data(SpottedSucker1)
     sv <- list(Linf=max(SpottedSucker1$tl),K=0.3,t0=0)
-    expect_warning(vbStarts(tl~age,data=SpottedSucker1,type="typical"))
+    expect_warning(vbStarts(tl~age,data=SpottedSucker1,param="typical"))
   }
 })
 
@@ -44,76 +47,76 @@ test_that("vbStarts() output",{
   if (require(fishmethods)) {
     data(Kimura)
     ## Returns a list with proper names
-    tmp <- vbStarts(length~age,data=Kimura,type="typical")
+    tmp <- vbStarts(length~age,data=Kimura,param="typical")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="typical",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="typical",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="BevertonHolt")
+    tmp <- vbStarts(length~age,data=Kimura,param="BevertonHolt")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="BevertonHolt",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="BevertonHolt",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="original")
+    tmp <- vbStarts(length~age,data=Kimura,param="original")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","L0","K"))
-    tmp <- vbStarts(length~age,data=Kimura,type="original",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="original",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","L0","K"))
-    tmp <- vbStarts(length~age,data=Kimura,type="vonBertalanffy")
+    tmp <- vbStarts(length~age,data=Kimura,param="vonBertalanffy")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","L0","K"))
-    tmp <- vbStarts(length~age,data=Kimura,type="vonBertalanffy",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="vonBertalanffy",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","L0","K"))
-    tmp <- vbStarts(length~age,data=Kimura,type="GQ")
+    tmp <- vbStarts(length~age,data=Kimura,param="GQ")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("omega","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="GQ",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="GQ",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("omega","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="GallucciQuinn")
+    tmp <- vbStarts(length~age,data=Kimura,param="GallucciQuinn")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("omega","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="GallucciQuinn",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="GallucciQuinn",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("omega","K","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Mooij")
+    tmp <- vbStarts(length~age,data=Kimura,param="Mooij")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","L0","omega"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Mooij",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="Mooij",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","L0","omega"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Weisberg")
+    tmp <- vbStarts(length~age,data=Kimura,param="Weisberg")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","t50","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Weisberg",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="Weisberg",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","t50","t0"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Schnute",ages2use=c(1,10))
+    tmp <- vbStarts(length~age,data=Kimura,param="Schnute",ages2use=c(1,10))
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("L1","L3","K"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Schnute",ages2use=c(1,10),methEV="means")
+    tmp <- vbStarts(length~age,data=Kimura,param="Schnute",ages2use=c(1,10),methEV="means")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("L1","L3","K"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Francis",ages2use=c(1,10))
+    tmp <- vbStarts(length~age,data=Kimura,param="Francis",ages2use=c(1,10))
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("L1","L2","L3"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Francis",ages2use=c(1,10),methEV="means")
+    tmp <- vbStarts(length~age,data=Kimura,param="Francis",ages2use=c(1,10),methEV="means")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("L1","L2","L3"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Somers")
+    tmp <- vbStarts(length~age,data=Kimura,param="Somers")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0","C","ts"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Somers",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="Somers",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0","C","ts"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Somers2")
+    tmp <- vbStarts(length~age,data=Kimura,param="Somers2")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0","C","WP"))
-    tmp <- vbStarts(length~age,data=Kimura,type="Somers2",meth0="yngAge")
+    tmp <- vbStarts(length~age,data=Kimura,param="Somers2",meth0="yngAge")
     expect_is(tmp,"list")
     expect_equal(names(tmp),c("Linf","K","t0","C","WP"))
   }  
@@ -132,7 +135,7 @@ test_that("vbFuns() and vbStarts() fit to Kimura match Haddon book (2nd ed, p237
     vbT <- vbFuns("typical")
     ## Examine females
     KimuraF <- Subset(Kimura,sex=="F")
-    svF <- vbStarts(length~age,data=KimuraF,type="typical")
+    svF <- vbStarts(length~age,data=KimuraF,param="typical")
     fitF <- nls(length~vbT(age,Linf,K,t0),data=KimuraF,start=svF)
     cfF <- coef(fitF)
     # double brackets to remove name attribute
@@ -141,7 +144,7 @@ test_that("vbFuns() and vbStarts() fit to Kimura match Haddon book (2nd ed, p237
     expect_equal(round(cfF[["t0"]],4),-0.0573)
     ## Examine males
     KimuraM <- Subset(Kimura,sex=="M")
-    svM <- vbStarts(length~age,data=KimuraM,type="typical")
+    svM <- vbStarts(length~age,data=KimuraM,param="typical")
     fitM <- nls(length~vbT(age,Linf,K,t0),data=KimuraM,start=svM)
     cfM <- coef(fitM)
     expect_equal(round(cfM[["Linf"]],2),55.98)
